summaryrefslogtreecommitdiff
path: root/cpp/src/qpid/client/amqp0_10/SessionImpl.cpp
diff options
context:
space:
mode:
authorGordon Sim <gsim@apache.org>2010-01-27 10:42:19 +0000
committerGordon Sim <gsim@apache.org>2010-01-27 10:42:19 +0000
commitf13dceb97198486cd9bd9574babac6b39d05b1a6 (patch)
tree3e875358e2ba2a49fb7a27815c22a675e4f2e45b /cpp/src/qpid/client/amqp0_10/SessionImpl.cpp
parentc5f105c31896a42c4a192b9585016aa92285e6ff (diff)
downloadqpid-python-f13dceb97198486cd9bd9574babac6b39d05b1a6.tar.gz
QPID-664: change cancel() to close() for consistency
git-svn-id: https://svn.apache.org/repos/asf/qpid/trunk/qpid@903599 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'cpp/src/qpid/client/amqp0_10/SessionImpl.cpp')
-rw-r--r--cpp/src/qpid/client/amqp0_10/SessionImpl.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/cpp/src/qpid/client/amqp0_10/SessionImpl.cpp b/cpp/src/qpid/client/amqp0_10/SessionImpl.cpp
index 1343305174..62af6394b0 100644
--- a/cpp/src/qpid/client/amqp0_10/SessionImpl.cpp
+++ b/cpp/src/qpid/client/amqp0_10/SessionImpl.cpp
@@ -94,7 +94,7 @@ void SessionImpl::reject(qpid::messaging::Message& m)
void SessionImpl::close()
{
//cancel all the senders and receivers (get copy of names and then
//make the calls to avoid modifying maps while iterating over
//them):
std::vector<std::string> s;
@@ -104,8 +104,8 @@ void SessionImpl::close()
for (Senders::const_iterator i = senders.begin(); i != senders.end(); ++i) s.push_back(i->first);
for (Receivers::const_iterator i = receivers.begin(); i != receivers.end(); ++i) r.push_back(i->first);
}
- for (std::vector<std::string>::const_iterator i = s.begin(); i != s.end(); ++i) getSender(*i).cancel();
- for (std::vector<std::string>::const_iterator i = r.begin(); i != r.end(); ++i) getReceiver(*i).cancel();
+ for (std::vector<std::string>::const_iterator i = s.begin(); i != s.end(); ++i) getSender(*i).close();
+ for (std::vector<std::string>::const_iterator i = r.begin(); i != r.end(); ++i) getReceiver(*i).close();
connection.closed(*this);
@@ -94,7 +94,7 @@ void SessionImpl::reject(qpid::messaging::Message& m)
void SessionImpl::close()
{
- //cancel all the senders and receivers (get copy of names and then
+ //close all the senders and receivers (get copy of names and then
//make the calls to avoid modifying maps while iterating over
//them):